@@ -12,7 +12,6 @@
 #include "TDecompSparse.h"
 #include "TMath.h"
 
-ClassImp(TDecompSparse);
 
 /** \class TDecompSparse
     \ingroup Matrix
@@ -211,7 +210,7 @@ void TDecompSparse::SetMatrix(const TMatrixDSparse &a)
          return;
       case 1 :
          Error("SetMatrix(const TMatrixDSparse &",
-               "detected %d entries out of rage in row/col indices; ignored",this->IError());
+               "detected %d entries out of range in row/col indices; ignored",this->IError());
          return;
    }
 
@@ -345,12 +344,6 @@ Bool_t TDecompSparse::Solve(TVectorD &b)
       Error("Solve()","Matrix is singular");
       return kFALSE;
    }
-   if ( !TestBit(kDecomposed) ) {
-      if (!Decompose()) {
-         Error("Solve()","Decomposition failed");
-         return kFALSE;
-      }
-   }
 
    if (fNrows != b.GetNrows() || fRowLwb != b.GetLwb())
    {
@@ -371,6 +364,13 @@ Bool_t TDecompSparse::Solve(TVectorD &b)
 
    while (!done && refactorizations < 10) {
 
+      if (!TestBit(kDecomposed)) {
+         if (!Decompose()) {
+            Error("Solve()", "Decomposition failed");
+            return kFALSE;
+         }
+      }
+
       Solve(fNrows,fFact,fIw,fW,fMaxfrt,b,fIw1,fNsteps,fIcntl,fInfo);
 
       // compute residuals
@@ -754,7 +754,7 @@ void TDecompSparse::Solve(const Int_t n,TArrayD &Aa,TArrayI &Aiw,
    info[1] = 0;
    k = 0;
    if (icntl[3] > 0 && icntl[2] > 0) {
-      printf("nentering Solve with n=%d la=%d liw=%d maxfrt=%d nsteps=%d",n,la,liw,maxfrt,nsteps);
+      printf("Entering Solve with n=%d la=%d liw=%d maxfrt=%d nsteps=%d", n, la, liw, maxfrt, nsteps);
 
       kblk = TMath::Abs(iw[1]+0);
       if (kblk != 0) {
